@@ -301,19 +301,19 @@ class AxiStreamHandler():
             hw_classifications = []
             print(len(outputs))
             for outcome in outputs:
-                probs = []
                 for out in outcome:
-                
+                    probs = []
                     if self.model_specs["data_type"][:3] == "fps":
                         for i in range(0, self.n_output):
+                            print(out[i])
                             if self.benchcore == True and i == self.n_output - 1:
                                 clock_cycles.append(out[i])
                             else:
                                 prob = self.__fixed_to_float(out[i])
                                 probs.append(prob)
 
-                classification = np.argmax(probs)
-                hw_classifications.append(int(classification))
+                    classification = np.argmax(probs)
+                    hw_classifications.append(int(classification))
             
             preds = hw_classifications
 
@@ -341,8 +341,8 @@ class AxiStreamHandler():
             hw_classifications = []
             clock_cycles = []
             for outcome in outputs:
-                probs = []
                 for out in outcome:
+                    probs = []
                     if self.model_specs['register_size'] == 16:
                         for i in range(0, self.n_output):
                             if self.benchcore == True and i == self.n_output - 1:
@@ -361,8 +361,8 @@ class AxiStreamHandler():
                                 prob_float = self.__bin_to_float32(binary_str)
                                 probs.append(prob_float)
             
-                classification = np.argmax(probs)
-                hw_classifications.append(int(classification))
+                    classification = np.argmax(probs)
+                    hw_classifications.append(int(classification))
             
             preds = hw_classifications
 
@@ -384,9 +384,11 @@ class AxiStreamHandler():
 
             for i in range(0, len(self.batches)):
                 input_buffer[:]=self.batches[i]
+                print("input buffer: ", input_buffer)
                 output_buffer = allocate(shape=self.output_shape, dtype=data_type_output)
                 if debug:
                     start_time = time.time()
+                print("Before transfer")
                 self.sendchannel.transfer(input_buffer)
                 self.recvchannel.transfer(output_buffer)
                 self.sendchannel.wait()
